@@ -1,3 +1,4 @@
+import tkinter.messagebox
 from threading import Thread
 from tkinter import Tk, Button
 
@@ -7,24 +8,29 @@ from dvpn.modules.vpncli import VpnCli
 
 
 def connect_threaded(window, host, instigator):
-    Thread(target=_connect_threaded, args=[window, host, instigator]).start()
+    Thread(target=_connect_threaded, args=[window, host, instigator], daemon=True).start()
 
 
 def disconnect_threaded(window: Tk):
-    Thread(target=_disconnect_threaded, args=[window]).start()
+    Thread(target=_disconnect_threaded, args=[window], daemon=True).start()
+
 
 
 def _connect_threaded(window: Tk, host, instigator: Button):
     window.title(f"DieVPN Connecting to {host}")
-    state_buttons("disabled")
+    # state_buttons("disabled")
     clear_buttons()
-    if connect(host):
+    stat = connect(host)
+    if stat[0]:
         instigator.config(bg="darkgreen")
         window.title(f"DieVPN Connected to {host}")
     else:
         instigator.config(bg="darkred")
         window.title("Die VPN Control")
-    state_buttons("normal")
+        if stat[1].get("reason", False) == "invalid credentials":
+            tkinter.messagebox.showerror("Invalid Credentials",
+                                         f"Invalid Login Credentials for VPN {host}")
+    # state_buttons("normal")
 
 
 def _disconnect_threaded(window: Tk):
